@@ -10,6 +10,8 @@ from PyQt5 import uic, QtCore, QtWidgets
 from ... import meta_tool
 from ...pipeline import Dataslot
 
+from .dlg_slot_reorder import DlgSlotReorder
+
 
 class SlotPanel(QtWidgets.QWidget):
     #: Emitted when a shapeout2.pipeline.Dataslot is to be changed
@@ -25,9 +27,10 @@ class SlotPanel(QtWidgets.QWidget):
         # current Shape-Out 2 pipeline
         self._pipeline = None
         # signals
-        self.pushButton_anew.clicked.connect(self.on_anew_slot)
-        self.pushButton_duplicate.clicked.connect(self.on_duplicate_slot)
-        self.pushButton_remove.clicked.connect(self.on_remove_slot)
+        self.toolButton_reorder.clicked.connect(self.on_reorder_slots)
+        self.toolButton_anew.clicked.connect(self.on_anew_slot)
+        self.toolButton_duplicate.clicked.connect(self.on_duplicate_slot)
+        self.toolButton_remove.clicked.connect(self.on_remove_slot)
         self.pushButton_apply.clicked.connect(self.write_slot)
         self.pushButton_reset.clicked.connect(self.update_content)
         self.comboBox_slots.currentIndexChanged.connect(self.update_content)
@@ -187,14 +190,14 @@ class SlotPanel(QtWidgets.QWidget):
         if medium in KNOWN_MEDIA:
             valid_media = [medium]
         else:
-            valid_media = KNOWN_MEDIA + ["other", "undefined"]
+            valid_media = KNOWN_MEDIA + [medium, "other", "undefined"]
         choices = []
         for vm in valid_media:
             if vm == "CellCarrierB":
                 name = "CellCarrier B"  # [sic]
             else:
                 name = vm
-            choices.append([name, medium])
+            choices.append([name, vm])
         return choices
 
     @staticmethod
@@ -321,6 +324,13 @@ class SlotPanel(QtWidgets.QWidget):
         state = self.pipeline.__getstate__()
         self.pipeline_changed.emit(state)
 
+    @QtCore.pyqtSlot()
+    def on_reorder_slots(self):
+        """Open dialog for reordering slots"""
+        dlg = DlgSlotReorder(self.pipeline, self)
+        dlg.pipeline_changed.connect(self.pipeline_changed)
+        dlg.exec()
+
     @QtCore.pyqtSlot()
     def on_ui_changed(self):
         """Called when the user modifies the medium or temperature options"""
